==> chaosmesh-model-6.7.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/DNSChaosBuilder.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class DNSChaosBuilder extends DNSChaosFluentImpl<DNSChaosBuilder> implements VisitableBuilder<DNSChaos,DNSChaosBuilder>{
  public DNSChaosBuilder() {
    this(false);
  }
  public DNSChaosBuilder(Boolean validationEnabled) {
    this(new DNSChaos(), validationEnabled);
  }
  public DNSChaosBuilder(DNSChaosFluent<?> fluent) {
    this(fluent, false);
  }
  public DNSChaosBuilder(DNSChaosFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new DNSChaos(), validationEnabled);
  }
  public DNSChaosBuilder(DNSChaosFluent<?> fluent,DNSChaos instance) {
    this(fluent, instance, false);
  }
  public DNSChaosBuilder(DNSChaosFluent<?> fluent,DNSChaos instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withSpec(instance.getSpec());
      fluent.withStatus(instance.getStatus());
    }
    this.validationEnabled = validationEnabled; 
  }
  public DNSChaosBuilder(DNSChaos instance) {
    this(instance,false);
  }
  public DNSChaosBuilder(DNSChaos instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
    }
    this.validationEnabled = validationEnabled; 
  }
  DNSChaosFluent<?> fluent;
  Boolean validationEnabled;
  public DNSChaos build() {
    DNSChaos buildable = new DNSChaos(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    return buildable;
  }
  
}

==> chaosmesh-model-6.8.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/DNSChaosBuilder.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class DNSChaosBuilder extends DNSChaosFluent<DNSChaosBuilder> implements VisitableBuilder<DNSChaos,DNSChaosBuilder>{
  public DNSChaosBuilder() {
    this(false);
  }
  public DNSChaosBuilder(Boolean validationEnabled) {
    this(new DNSChaos(), validationEnabled);
  }
  public DNSChaosBuilder(DNSChaosFluent<?> fluent) {
    this(fluent, false);
  }
  public DNSChaosBuilder(DNSChaosFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new DNSChaos(), validationEnabled);
  }
  public DNSChaosBuilder(DNSChaosFluent<?> fluent,DNSChaos instance) {
    this(fluent, instance, false);
  }
  public DNSChaosBuilder(DNSChaosFluent<?> fluent,DNSChaos instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new DNSChaos());

    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withSpec(instance.getSpec());
      fluent.withStatus(instance.getStatus());
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withSpec(instance.getSpec());
      fluent.withStatus(instance.getStatus());
    }
    this.validationEnabled = validationEnabled; 
  }
  public DNSChaosBuilder(DNSChaos instance) {
    this(instance,false);
  }
  public DNSChaosBuilder(DNSChaos instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new DNSChaos());

    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
    }
    this.validationEnabled = validationEnabled; 
  }
  DNSChaosFluent<?> fluent;
  Boolean validationEnabled;
  public DNSChaos build() {
    DNSChaos buildable = new DNSChaos(fluent.getApiVersion(),fluent.getKind(),fluent.buildMetadata(),fluent.buildSpec(),fluent.buildStatus());
    return buildable;
  }
  
}
